package compbio.beans;

import java.util.ArrayList;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

import compbio.cassandra.PredictionIndex;

/**
 * POJO bean with information on a protein
 * 
 * @author Natasha Sherstneva
 * 
 * @version 1.0
 * @since Jan 2014
 */
public class ProteinBean implements PredictionIndex {
	private String sequence; // protein sequence
	private String jnetpred; // the main Jpred prediction sequence
	private List<String> jobid;  // job IDd: all jobs with the protein
	private LinkedHashMap<String, String> predictions; // predictions: Key - prediction ID, Value - prediction sequence
	private List<String> subProt; // protein sequence divided in several parts
									// for highlighting a particular part
	private int size; // a number of predictions for the protein

	public ProteinBean(String seq, Map<String, String> pred) {
		this.sequence = seq;
		this.predictions = new LinkedHashMap<String, String>();
		this.jobid = new ArrayList<String>();
		setPredictions(pred);
		setJnetpred(pred);
	}

	public void setSequence(String seq) {
		this.sequence = seq;
	}

	public void setPredictions(Map<String, String> pred) {
		if (predictions == null)
			predictions = new LinkedHashMap<String, String>();
		for (String index : predIndex) {
			this.predictions.put(index, pred.get(index));
		}
		this.size = predictions.size();
	}

	public String getSequence() {
		return sequence;
	}

	public String getJnetpred() {
		return jnetpred;
	}

	public void setJnetpred(Map<String, String> pred) {
		if (pred != null) {
			if (pred.containsKey("jnetpred"))
				jnetpred = pred.get("jnetpred");
		}
	}

	public List<String> getJobid() {
		return jobid;
	}

	public void setJobid(String id) {
		this.jobid.add(id);
	}

	public int getSize() {
		return size;
	}

	public LinkedHashMap<String, String> getPredictions() {
		return predictions;
	}

	public void setSubProt(List<String> subProt) {
		this.subProt = subProt;
	}

	public List<String> getSubProt() {
		return subProt;
	}

}
